pub struct Receipts {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl Receipts
impl Receipts
Sourcepub async fn get_page(
&self,
from_date: Option<DateTime<Utc>>,
to_date: Option<DateTime<Utc>>,
created_after: Option<DateTime<Utc>>,
created_before: Option<DateTime<Utc>>,
start: &str,
page_size: f64,
) -> Result<Response<Vec<Receipt>>, ClientError>
pub async fn get_page( &self, from_date: Option<DateTime<Utc>>, to_date: Option<DateTime<Utc>>, created_after: Option<DateTime<Utc>>, created_before: Option<DateTime<Utc>>, start: &str, page_size: f64, ) -> Result<Response<Vec<Receipt>>, ClientError>
List receipts.
This function performs a GET to the /receipts endpoint.
Returns description of all receipts of a business.
Parameters:
from_date: chrono::DateTime<chrono::Utc>– Filter for receipts related to transactions which occurred after the specified date.to_date: chrono::DateTime<chrono::Utc>– Filter for receipts related to transactions which occurred before the specified date.created_after: chrono::DateTime<chrono::Utc>– Filter for receipts that were created after the specified date.created_before: chrono::DateTime<chrono::Utc>– Filter for receipts that were created before the specified date.start: &str– The ID of the last entity of the previous page, used for pagination to get the next page.page_size: f64– The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
Sourcepub async fn get_all(
&self,
from_date: Option<DateTime<Utc>>,
to_date: Option<DateTime<Utc>>,
created_after: Option<DateTime<Utc>>,
created_before: Option<DateTime<Utc>>,
) -> Result<Response<Vec<Receipt>>, ClientError>
pub async fn get_all( &self, from_date: Option<DateTime<Utc>>, to_date: Option<DateTime<Utc>>, created_after: Option<DateTime<Utc>>, created_before: Option<DateTime<Utc>>, ) -> Result<Response<Vec<Receipt>>, ClientError>
List receipts.
This function performs a GET to the /receipts endpoint.
As opposed to get, this function returns all the pages of the request at once.
Returns description of all receipts of a business.