pub struct Transactions {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl Transactions
impl Transactions
Sourcepub async fn get_page(
&self,
department_id: &str,
location_id: &str,
from_date: Option<DateTime<Utc>>,
to_date: Option<DateTime<Utc>>,
merchant_id: &str,
sk_category_id: &str,
order_by_date_desc: bool,
order_by_date_asc: bool,
order_by_amount_desc: bool,
order_by_amount_asc: bool,
state: &str,
min_amount: f64,
max_amount: f64,
start: &str,
page_size: f64,
requires_memo: bool,
) -> Result<Response<Vec<Data>>, ClientError>
pub async fn get_page( &self, department_id: &str, location_id: &str, from_date: Option<DateTime<Utc>>, to_date: Option<DateTime<Utc>>, merchant_id: &str, sk_category_id: &str, order_by_date_desc: bool, order_by_date_asc: bool, order_by_amount_desc: bool, order_by_amount_asc: bool, state: &str, min_amount: f64, max_amount: f64, start: &str, page_size: f64, requires_memo: bool, ) -> Result<Response<Vec<Data>>, ClientError>
List transactions.
This function performs a GET to the /transactions endpoint.
Retrieves all transactions for the business. This endpoint supports filtering and ordering. NOTE: only one ordering param is supported.
Parameters:
authorization: &str– The OAuth2 token header.department_id: &str– The OAuth2 token header.location_id: &str– The OAuth2 token header.from_date: chrono::DateTime<chrono::Utc>to_date: chrono::DateTime<chrono::Utc>merchant_id: &str– The OAuth2 token header.sk_category_id: &str– The OAuth2 token header.order_by_date_desc: boolorder_by_date_asc: boolorder_by_amount_desc: boolorder_by_amount_asc: boolstate: &str– The OAuth2 token header.min_amount: f64– The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.max_amount: f64– The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.start: &str– The ID of the last entity of the previous page, used for pagination to get the next page.page_size: f64– The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.requires_memo: bool– Filters for transactions which require a memo, but do not have one. This can only be set to true.
Sourcepub async fn get_all(
&self,
department_id: &str,
location_id: &str,
from_date: Option<DateTime<Utc>>,
to_date: Option<DateTime<Utc>>,
merchant_id: &str,
sk_category_id: &str,
order_by_date_desc: bool,
order_by_date_asc: bool,
order_by_amount_desc: bool,
order_by_amount_asc: bool,
state: &str,
min_amount: f64,
max_amount: f64,
requires_memo: bool,
) -> Result<Response<Vec<Data>>, ClientError>
pub async fn get_all( &self, department_id: &str, location_id: &str, from_date: Option<DateTime<Utc>>, to_date: Option<DateTime<Utc>>, merchant_id: &str, sk_category_id: &str, order_by_date_desc: bool, order_by_date_asc: bool, order_by_amount_desc: bool, order_by_amount_asc: bool, state: &str, min_amount: f64, max_amount: f64, requires_memo: bool, ) -> Result<Response<Vec<Data>>, ClientError>
List transactions.
This function performs a GET to the /transactions endpoint.
As opposed to get, this function returns all the pages of the request at once.
Retrieves all transactions for the business. This endpoint supports filtering and ordering. NOTE: only one ordering param is supported.
Sourcepub async fn get_resource(
&self,
id: &str,
) -> Result<Response<Data>, ClientError>
pub async fn get_resource( &self, id: &str, ) -> Result<Response<Data>, ClientError>
GET a transaction.
This function performs a GET to the /transactions/{id} endpoint.
Parameters:
authorization: &str– The OAuth2 token header.