pub struct Business {Show 15 fields
pub active: bool,
pub billing_address: BillingAddress,
pub business_memo_required_threshold: f64,
pub business_name_legal: String,
pub business_name_on_card: String,
pub business_receipt_required_threshold: f64,
pub created_time: String,
pub enforce_sso: bool,
pub id: String,
pub initial_approved_limit: f64,
pub is_integrated_with_slack: bool,
pub is_reimbursements_enabled: bool,
pub limit_locked: bool,
pub phone: String,
pub website: String,
}Expand description
Mostly static information about a business that doesn’t change often.
Fields
active: boolbilling_address: BillingAddressbusiness_memo_required_threshold: f64The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
business_name_legal: StringThe OAuth2 token header
business_name_on_card: StringMostly static information about a business that doesn’t change often.
business_receipt_required_threshold: f64The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
created_time: StringThe OAuth2 token header
enforce_sso: boolid: StringThe OAuth2 token header
initial_approved_limit: f64The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
is_integrated_with_slack: boolis_reimbursements_enabled: boollimit_locked: boolphone: StringThe OAuth2 token header
website: StringThe OAuth2 token header