pub struct Card {
pub card_program_id: String,
pub cardholder_id: String,
pub cardholder_name: String,
pub display_name: String,
pub fulfillment: Option<Fulfillment>,
pub id: String,
pub is_physical: bool,
pub last_four: String,
pub spending_restrictions: Option<SpendingRestrictions>,
}Expand description
Card data that holds mostly static information about a card.
Fields
card_program_id: StringCard data that holds mostly static information about a card.
cardholder_id: StringCard data that holds mostly static information about a card.
cardholder_name: StringCard data that holds mostly static information about a card.
display_name: StringCard data that holds mostly static information about a card.
fulfillment: Option<Fulfillment>Card data that holds mostly static information about a card.
id: StringCard data that holds mostly static information about a card.
is_physical: boolCard data that holds mostly static information about a card.
last_four: StringCard data that holds mostly static information about a card.
spending_restrictions: Option<SpendingRestrictions>Card data that holds mostly static information about a card.