Struct ramp_api::types::ErrorResponse
source · [−]Fields
error: Option<Error>Trait Implementations
sourceimpl Clone for ErrorResponse
impl Clone for ErrorResponse
sourcefn clone(&self) -> ErrorResponse
fn clone(&self) -> ErrorResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ErrorResponse
impl Debug for ErrorResponse
sourceimpl<'de> Deserialize<'de> for ErrorResponse
impl<'de> Deserialize<'de> for ErrorResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ErrorResponse
impl JsonSchema for ErrorResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<ErrorResponse> for ErrorResponse
impl PartialEq<ErrorResponse> for ErrorResponse
sourcefn eq(&self, other: &ErrorResponse) -> bool
fn eq(&self, other: &ErrorResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ErrorResponse) -> bool
fn ne(&self, other: &ErrorResponse) -> bool
This method tests for !=.
sourceimpl Serialize for ErrorResponse
impl Serialize for ErrorResponse
impl StructuralPartialEq for ErrorResponse