Struct ramp_api::types::GetDepartmentsResponse
source · [−]pub struct GetDepartmentsResponse {
pub data: Vec<Department>,
pub page: Page,
}Fields
data: Vec<Department>page: PageTrait Implementations
sourceimpl Clone for GetDepartmentsResponse
impl Clone for GetDepartmentsResponse
sourcefn clone(&self) -> GetDepartmentsResponse
fn clone(&self) -> GetDepartmentsResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for GetDepartmentsResponse
impl Debug for GetDepartmentsResponse
sourceimpl<'de> Deserialize<'de> for GetDepartmentsResponse
impl<'de> Deserialize<'de> for GetDepartmentsResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetDepartmentsResponse
impl JsonSchema for GetDepartmentsResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<GetDepartmentsResponse> for GetDepartmentsResponse
impl PartialEq<GetDepartmentsResponse> for GetDepartmentsResponse
sourcefn eq(&self, other: &GetDepartmentsResponse) -> bool
fn eq(&self, other: &GetDepartmentsResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &GetDepartmentsResponse) -> bool
fn ne(&self, other: &GetDepartmentsResponse) -> bool
This method tests for !=.
sourceimpl Serialize for GetDepartmentsResponse
impl Serialize for GetDepartmentsResponse
impl StructuralPartialEq for GetDepartmentsResponse