Struct ramp_api::types::GetReceiptsResponse
source · [−]Fields
data: Vec<Receipt>page: PageTrait Implementations
sourceimpl Clone for GetReceiptsResponse
impl Clone for GetReceiptsResponse
sourcefn clone(&self) -> GetReceiptsResponse
fn clone(&self) -> GetReceiptsResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for GetReceiptsResponse
impl Debug for GetReceiptsResponse
sourceimpl<'de> Deserialize<'de> for GetReceiptsResponse
impl<'de> Deserialize<'de> for GetReceiptsResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetReceiptsResponse
impl JsonSchema for GetReceiptsResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<GetReceiptsResponse> for GetReceiptsResponse
impl PartialEq<GetReceiptsResponse> for GetReceiptsResponse
sourcefn eq(&self, other: &GetReceiptsResponse) -> bool
fn eq(&self, other: &GetReceiptsResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &GetReceiptsResponse) -> bool
fn ne(&self, other: &GetReceiptsResponse) -> bool
This method tests for !=.
sourceimpl Serialize for GetReceiptsResponse
impl Serialize for GetReceiptsResponse
impl StructuralPartialEq for GetReceiptsResponse