Struct ramp_api::types::GetReimbursementsResponse
source · [−]pub struct GetReimbursementsResponse {
pub data: Vec<Reimbursement>,
pub page: Page,
}Fields
data: Vec<Reimbursement>page: PageTrait Implementations
sourceimpl Clone for GetReimbursementsResponse
impl Clone for GetReimbursementsResponse
sourcefn clone(&self) -> GetReimbursementsResponse
fn clone(&self) -> GetReimbursementsResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for GetReimbursementsResponse
impl Debug for GetReimbursementsResponse
sourceimpl<'de> Deserialize<'de> for GetReimbursementsResponse
impl<'de> Deserialize<'de> for GetReimbursementsResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetReimbursementsResponse
impl JsonSchema for GetReimbursementsResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<GetReimbursementsResponse> for GetReimbursementsResponse
impl PartialEq<GetReimbursementsResponse> for GetReimbursementsResponse
sourcefn eq(&self, other: &GetReimbursementsResponse) -> bool
fn eq(&self, other: &GetReimbursementsResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &GetReimbursementsResponse) -> bool
fn ne(&self, other: &GetReimbursementsResponse) -> bool
This method tests for !=.
sourceimpl Serialize for GetReimbursementsResponse
impl Serialize for GetReimbursementsResponse
impl StructuralPartialEq for GetReimbursementsResponse