Struct ramp_api::types::GetUsersResponse
source · [−]Expand description
Fields
data: Vec<User>page: PageTrait Implementations
sourceimpl Clone for GetUsersResponse
impl Clone for GetUsersResponse
sourcefn clone(&self) -> GetUsersResponse
fn clone(&self) -> GetUsersResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for GetUsersResponse
impl Debug for GetUsersResponse
sourceimpl<'de> Deserialize<'de> for GetUsersResponse
impl<'de> Deserialize<'de> for GetUsersResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetUsersResponse
impl JsonSchema for GetUsersResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<GetUsersResponse> for GetUsersResponse
impl PartialEq<GetUsersResponse> for GetUsersResponse
sourcefn eq(&self, other: &GetUsersResponse) -> bool
fn eq(&self, other: &GetUsersResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &GetUsersResponse) -> bool
fn ne(&self, other: &GetUsersResponse) -> bool
This method tests for !=.
sourceimpl Serialize for GetUsersResponse
impl Serialize for GetUsersResponse
impl StructuralPartialEq for GetUsersResponse