Struct ramp_api::types::Reimbursement
source · [−]pub struct Reimbursement {
pub amount: f64,
pub created_at: Option<DateTime<Utc>>,
pub currency: String,
pub id: String,
pub merchant: String,
pub receipts: Vec<String>,
pub transaction_date: Option<NaiveDate>,
pub user_id: String,
}Fields
amount: f64created_at: Option<DateTime<Utc>>currency: Stringid: Stringmerchant: Stringreceipts: Vec<String>transaction_date: Option<NaiveDate>user_id: StringTrait Implementations
sourceimpl Clone for Reimbursement
impl Clone for Reimbursement
sourcefn clone(&self) -> Reimbursement
fn clone(&self) -> Reimbursement
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for Reimbursement
impl Debug for Reimbursement
sourceimpl<'de> Deserialize<'de> for Reimbursement
impl<'de> Deserialize<'de> for Reimbursement
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for Reimbursement
impl JsonSchema for Reimbursement
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<Reimbursement> for Reimbursement
impl PartialEq<Reimbursement> for Reimbursement
sourcefn eq(&self, other: &Reimbursement) -> bool
fn eq(&self, other: &Reimbursement) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &Reimbursement) -> bool
fn ne(&self, other: &Reimbursement) -> bool
This method tests for !=.
sourceimpl Serialize for Reimbursement
impl Serialize for Reimbursement
impl StructuralPartialEq for Reimbursement